@@ -22,6 +22,14 @@ as.data.frame.freqlist <- function(x, ...)
 NULL
 #> NULL
 
+#' @rdname freqlist.internal
+#' @export
+is.freqlist <- function(x) inherits(x, "freqlist")
+
+#' @rdname freqlist.internal
+#' @export
+is.summary.freqlist <- function(x) inherits(x, "summary.freqlist")
+
 #' @rdname freqlist.internal
 #' @export
 'labels<-.freqlist' <- function(x, value) {
