@@ -7,10 +7,14 @@
 #' @param total logical, telling \code{tableby} whether to calculate a column of totals across group variable.
 #' @param test.pname character string denoting the p-value column name in \code{\link{summary.tableby}}.
 #'   Modifiable also with \code{\link{modpval.tableby}}.
-#' @param cat.simplify logical, tell \code{tableby} whether to include the first level of the categorical variable if binary.
-#'   If \code{TRUE}, only the summary stats of the second level, and total (if \code{TRUE}), are calculated.
-#'   NOTE: this only simplifies to one line if \code{cat.stats} is only one statistic, such as countpct.
-#'   Specifically, if \code{cat.stats} includes Nmiss and there are missings, then Nmiss is included in the stats.
+#' @param cat.simplify logical, tell \code{tableby} whether to remove the first level of the categorical variable if binary.
+#'   If \code{TRUE}, only the summary stats of the second level are reported.
+#'   NOTE: this only simplifies to one line if \code{cat.stats} is only one statistic, such as \code{countpct}.
+#'   In particular, if \code{cat.stats} also includes \code{Nmiss} and there are missings, then \code{cat.simplify} is ignored.
+#' @param numeric.simplify logical, tell \code{tableby} whether to condense numeric output to a single line.
+#'   NOTE: this only simplifies to one line if \code{numeric.stats} is only one statistic, such as \code{meansd}.
+#'   In particular, if \code{numeric.stats} also includes \code{Nmiss} and there are missings, then
+#'   \code{numeric.simplify} is ignored.
 #' @param numeric.test name of test for numeric RHS variables in \code{tableby}: anova, kwt (Kruskal-Wallis).
 #'   If no LHS variable exists, then a mean is required for a univariate test.
 #' @param numeric.stats summary statistics to include for numeric RHS variables within the levels of the group LHS variable.
@@ -71,7 +75,7 @@
 #' summary(outResp, text=TRUE)
 #' summary(outCtl, text=TRUE)
 #' @export
-tableby.control <- function(test=TRUE,total=TRUE, test.pname=NULL, cat.simplify=FALSE,
+tableby.control <- function(test=TRUE,total=TRUE, test.pname=NULL, cat.simplify=FALSE, numeric.simplify=FALSE,
    numeric.test="anova", cat.test="chisq", ordered.test="trend", surv.test="logrank", date.test="kwt",
    numeric.stats=c("Nmiss","meansd","range"), cat.stats=c("Nmiss","countpct"),
    ordered.stats=c("Nmiss", "countpct"), surv.stats=c("Nevents","medSurv"), date.stats=c("Nmiss", "median","range"),
@@ -143,7 +147,7 @@ tableby.control <- function(test=TRUE,total=TRUE, test.pname=NULL, cat.simplify=
     stop("One or more date summary statistic functions do not exist.\n")
   }
 
-  list(test=test, total=total, test.pname=test.pname, cat.simplify=cat.simplify,
+  list(test=test, total=total, test.pname=test.pname, cat.simplify=cat.simplify, numeric.simplify=numeric.simplify,
        numeric.test=numeric.test, cat.test=cat.test,
        ordered.test=ordered.test, surv.test=surv.test,
        numeric.stats=numeric.stats, cat.stats=cat.stats,
